@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = 'v0.203.0';
+our $VERSION = 'v0.204.0';
 
 
 use Role::Declare -lax;
@@ -17,6 +17,11 @@ use Types::Common::Numeric qw/PositiveNum PositiveOrZeroNum/;
 use namespace::clean;
 
 
+instance_method get_context(
+) :Return(SpanContext) {}
+
+
+
 instance_method overwrite_operation_name(
     Str $operation_name
 ) :ReturnSelf {}
@@ -44,6 +49,11 @@ instance_method add_tags(
 
 
 
+instance_method get_tags(
+) :ReturnList(Any) {}
+
+
+
 instance_method log_data(
     %key_values
 ) :ReturnSelf {
@@ -67,4 +77,15 @@ instance_method add_baggage_items(
 
 
 
+instance_method get_baggage_item(
+    Str $key
+) :ReturnMaybe(Value) {}
+
+
+
+instance_method get_baggage_items(
+) :ReturnList(Any) {}
+
+
+
 1;
